# ASAS-EGB

ASAS-EGB is a library for estimating allele-specific
alternative splicing events using transcriptome data.
It is released as a Python package which requires
Python 3.7 or higher to be installed on the computer.
